Error

Enum Error 

#[non_exhaustive]
pub enum Error { BufferTooShort { need: usize, have: usize, what: &'static str, }, OutputBufferTooSmall { need: usize, have: usize, }, NotEmsg { found: [u8; 4], }, InvalidSize { size: u32, reason: &'static str, }, UnsupportedVersion { version: u8, }, InvalidString { field: &'static str, reason: &'static str, }, FieldTooWide { what: &'static str, value: u64, bits: u32, }, }
An emsg parse / serialize error.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


BufferTooShort

Input shorter than required.

Fields

need: usize

Bytes required.

have: usize

Bytes available.

what: &'static str

What was being parsed.



OutputBufferTooSmall

The output buffer passed to serialize_into was too small.

Fields

need: usize

Bytes required.

have: usize

Bytes available.



NotEmsg

The box type at bytes [4:8] was not emsg.

Fields

found: [u8; 4]

The 4-byte box type actually found.



InvalidSize

The size field is inconsistent with the available bytes (it must be at least the fixed header + cover the box, and 0 / 1 large-size forms are not supported for emsg).

Fields

size: u32

The size field value.

reason: &'static str

Why it is invalid.



UnsupportedVersion

The FullBox version was neither 0 nor 1.

Fields

version: u8

The version byte read from the wire.



InvalidString

A null-terminated UTF-8 string field was malformed (no terminator, or invalid UTF-8).

Fields

field: &'static str

Which string field (scheme_id_uri / value).

reason: &'static str

Why it is invalid.



FieldTooWide

A field value did not fit in its wire bit-width (e.g. a box larger than u32::MAX).

Fields

what: &'static str

The over-wide field name.

value: u64

The offending value.

bits: u32

The field width on the wire.